"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const draft_js_1 = require("draft-js");
const draftjs_styles_1 = require("./draftjs-styles");
const fa_1 = require("react-icons/fa");
const draftjs_to_html_1 = __importDefault(require("draftjs-to-html"));
const draftjs_link_1 = require("./draftjs-link");
const draftjs_constants_1 = require("./draftjs-constants");
const DraftJsEditor = ({ onChange }) => {
    const decorator = new draft_js_1.CompositeDecorator([
        {
            strategy: draftjs_link_1.findLinkEntities,
            component: draftjs_link_1.Link,
        },
    ]);
    const [editorState, setEditorState] = react_1.default.useState(() => draft_js_1.EditorState.createEmpty(decorator));
    const editorRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        editorRef.current.focus();
    }, []);
    const handleKeyCommand = (command, editorState) => {
        const newState = draft_js_1.RichUtils.handleKeyCommand(editorState, command);
        if (newState) {
            onEditorChange(newState);
            return "handled";
        }
        return "not-handled";
    };
    const toggleBlockType = (blockType) => {
        onEditorChange(draft_js_1.RichUtils.toggleBlockType(editorState, blockType));
    };
    const toggleInlineStyle = (inlineStyle) => {
        onEditorChange(draft_js_1.RichUtils.toggleInlineStyle(editorState, inlineStyle));
    };
    const onLinkClick = (e) => {
        e.preventDefault();
        const selection = editorState.getSelection();
        const contentState = editorState.getCurrentContent();
        if (!selection.isCollapsed()) {
            const blockWithLinkAtBeginning = contentState.getBlockForKey(selection.getStartKey());
            const linkKey = blockWithLinkAtBeginning.getEntityAt(selection.getStartOffset());
            if (linkKey) {
                onEditorChange(draft_js_1.RichUtils.toggleLink(editorState, selection, null));
            }
            else {
                const href = window.prompt("URL:");
                if (!href) {
                    onEditorChange(draft_js_1.RichUtils.toggleLink(editorState, selection, null));
                    return "handled";
                }
                const contentWithEntity = contentState.createEntity("LINK", "MUTABLE", {
                    url: href,
                });
                const entityKey = contentWithEntity.getLastCreatedEntityKey();
                const newEditorState = draft_js_1.EditorState.set(editorState, {
                    currentContent: contentWithEntity,
                });
                onEditorChange(draft_js_1.RichUtils.toggleLink(newEditorState, selection, entityKey));
            }
        }
    };
    const onEditorChange = (es) => {
        setEditorState(es);
        const contentState = es.getCurrentContent();
        const rawContentState = (0, draft_js_1.convertToRaw)(contentState);
        const html = (0, draftjs_to_html_1.default)(rawContentState);
        onChange(html);
    };
    return (react_1.default.createElement(draftjs_styles_1.DsContainer, null,
        react_1.default.createElement(draftjs_styles_1.DsHeader, null,
            react_1.default.createElement(draftjs_styles_1.DsControl, null,
                draftjs_constants_1.inlineControls.map((control, index) => {
                    const currentStyle = editorState.getCurrentInlineStyle();
                    return (react_1.default.createElement(draftjs_styles_1.DsControlButton, { selected: currentStyle.has(control.name), key: index, onClick: () => toggleInlineStyle(control.name) }, control.icon));
                }),
                react_1.default.createElement(draftjs_styles_1.DsControlButton, { selected: (0, draftjs_link_1.isLinkSelected)(editorState), onClick: onLinkClick },
                    react_1.default.createElement(fa_1.FaLink, null))),
            react_1.default.createElement(draftjs_styles_1.DsControl, null, draftjs_constants_1.blockControls.map((control, index) => {
                const selection = editorState.getSelection();
                const blockType = editorState
                    .getCurrentContent()
                    .getBlockForKey(selection.getStartKey())
                    .getType();
                return (react_1.default.createElement(draftjs_styles_1.DsControlButton, { selected: control.name === blockType, key: index, onClick: () => toggleBlockType(control.name) }, control.icon));
            }))),
        react_1.default.createElement(draftjs_styles_1.DsEditor, null,
            react_1.default.createElement(draft_js_1.Editor, { editorState: editorState, onChange: onEditorChange, handleKeyCommand: handleKeyCommand, ref: editorRef }))));
};
exports.default = DraftJsEditor;
